@@ -1,4 +1,4 @@
-`design.lattice` <-
+design.lattice <-
 function(trt,r=3,serie=2,seed=0,kinds="Super-Duper",randomization=TRUE) {
 number<-10
 if(serie>0) number<-10^serie
